@@ -9,10 +9,12 @@ and current working folder have default_name.html (html report default execute_d
 or you should get the function file_path to read
 """
 # test executor exception
-auto_control_test_executor_exception_tag: str = "can't run AutoControl test"
-api_testka_test_executor_exception_tag: str = "can't run APITestka test"
-web_runner_test_executor_exception_tag: str = "can't run WebRunner test"
-load_density_test_executor_exception_tag: str = "can't run LoadDensity test"
+auto_control_test_executor_exception_tag: str = "can't run AutoControl"
+api_testka_test_executor_exception_tag: str = "can't run APITestka"
+web_runner_test_executor_exception_tag: str = "can't run WebRunner"
+load_density_test_executor_exception_tag: str = "can't run LoadDensity"
+# Install
+not_install_exception: str = "Please install package first, Can't find package"
 # ui exception
 wrong_test_data_format_exception_tag: str = "get the wrong test data format"
 # exec exception
