@@ -5,6 +5,8 @@ from os import walk
 from os.path import abspath
 from os.path import join
 
+from PySide6.QtWidgets import QFileDialog, QMainWindow
+
 
 def get_dir_files_as_list(dir_path: str = getcwd(), default_search_file_extension: str = ".json") -> list:
     """
@@ -20,9 +22,9 @@ def get_dir_files_as_list(dir_path: str = getcwd(), default_search_file_extensio
     ]
 
 
-def ask_and_get_dir_files_as_list(default_search_file_extension: str = ".json") -> list:
-    choose_dir = tkinter.filedialog.askdirectory()
+def ask_and_get_dir_files_as_list(main_window: QMainWindow, default_search_file_extension: str = ".json") -> list:
+    choose_dir = QFileDialog(parent=main_window).getExistingDirectory()
     if choose_dir is not None and choose_dir != "":
         return get_dir_files_as_list(choose_dir, default_search_file_extension)
     else:
-        print("no select any dir", file=sys.stderr)
+        print("Not select any dir", file=sys.stderr)
